read_cant_segment

Function read_cant_segment 

pub fn read_cant_segment(
    model: &Model,
    id: EntityId,
    units: AlignmentUnits,
) -> AlignmentResult<CantSegment>
Read one IfcAlignmentCantSegment referenced by id.

Fails if id is missing, is not an IfcAlignmentCantSegment, an attribute is missing or the wrong kind, HorizontalLength is negative, any value is non-finite, or exactly one of EndCantLeft/EndCantRight is supplied without the other.