pub fn read_horizontal_segment(
model: &Model,
id: EntityId,
units: AlignmentUnits,
) -> AlignmentResult<HorizontalSegment>Expand description
Read one IfcAlignmentHorizontalSegment referenced by id.
Fails if units is non-finite or non-positive, id is missing or not an
IfcAlignmentHorizontalSegment, StartPoint does not resolve to an
IfcCartesianPoint with at least two coordinates, an attribute is
missing or the wrong kind, any value is non-finite, or SegmentLength
is not positive.